def generate_preview(input_file, options):
    """
    Generates page preview as jpeg
    """
    pass
